@@ -23,7 +23,7 @@ def main():
 
 
 def daemon():
-    TBGatewayService("/etc/thingsboard-gateway/config/tb_gateway.yaml".replace('/', path.sep))
+    TBGatewayService("/etc/ndu-gateway/config/tb_gateway.yaml".replace('/', path.sep))
 
 
 if __name__ == '__main__':
